Module paths

Module paths 

Functions

detect_explicit_path
home_dir
normalize
persistence_path
Prefixes file name with the machines home plus storage path e.g. ~/.local/share/odds/
search_roots
Returns the roots from which the program is going to search for candidates; which are: the current working directory, home and potentially a git repository i.e. a folder containing .git.