pub struct Session {
pub entries: Vec<SessionEntry>,
/* private fields */
}Fields
entries: Vec<SessionEntry>Implementations
Sourceimpl Session
impl Session
pub fn current(&self) -> Option<&PathBuf>
pub fn previous(&self) -> Option<&PathBuf>
Sourcepub fn list(&self) -> &[SessionEntry]
pub fn list(&self) -> &[SessionEntry]
List all directories (most recent first).
pub fn contains(&self, path: &PathBuf) -> bool
Sourcepub fn load_or_new() -> Self
pub fn load_or_new() -> Self
Load the existing session or create and return a new one if the old one is expired or it doesn’t exist yet.