Functions
- detect_
explicit_ path - home_
dir - normalize
- persistence_
path - Prefixes file name with the machines home plus storage path e.g.
~/.local/share/odds/
- search_
roots - Returns the roots from which the program is going to search for candidates; which are: the current working directory, home and potentially a git repository i.e. a folder containing .git.